@@ -60,7 +60,7 @@ expect_null_linter <- function() {
 
     xml <- source_expression$xml_parsed_content
 
-    bad_expr <- xml2::xml_find_all(xml, xpath)
+    bad_expr <- xml_find_all(xml, xpath)
 
     matched_function <- xp_call_name(bad_expr)
     msg <- ifelse(
