@@ -29,8 +29,6 @@
 #'     \item{`xml_parsed_content` (`xml_document`) the XML parse tree of this
 #'          expression as given by [xmlparsedata::xml_parse_data()]}
 #'     \item{`content` (`character`) the same as `lines` as a single string (not split across lines)}
-#'     \item{(**Deprecated**) `find_line` (`function`) a function for returning lines in this expression}
-#'     \item{(**Deprecated**) `find_column` (`function`) a similar function for columns}
 #'   }
 #'
 #'   The final element of `expressions` is a list corresponding to the full file
@@ -101,7 +99,7 @@ get_source_expressions <- function(filename, lines = NULL) {
 
     if (!is.null(xml_parsed_content) && !is.na(xml_parsed_content)) {
       expression_xmls <- lapply(
-        xml2::xml_find_all(xml_parsed_content, "/exprlist/*"),
+        xml_find_all(xml_parsed_content, "/exprlist/*"),
         function(top_level_expr) xml2::xml_add_parent(xml2::xml_new_root(top_level_expr), "exprlist")
       )
       for (i in seq_along(expressions)) {
@@ -185,7 +183,7 @@ fixup_line <- function(line) {
 #'
 #' @noRd
 lint_parse_error_r43 <- function(e, source_expression) {
-  msg <- rex::re_substitutes(e$message, rex::rex(" (", except_some_of(")"), ")", end), "")
+  msg <- re_substitutes(e$message, rex(" (", except_some_of(")"), ")", end), "")
   line_number <- e$lineno
   column <- e$colno
   substr(msg, 1L, 1L) <- toupper(substr(msg, 1L, 1L))
@@ -265,6 +263,7 @@ lint_parse_error_r42 <- function(message_info, source_expression) {
 #' @noRd
 lint_parse_error_nonstandard <- function(e, source_expression) {
   if (grepl("invalid multibyte character in parser at line", e$message, fixed = TRUE)) {
+    # nocov start: platform-specific
     l <- as.integer(re_matches(
       e$message,
       rex("invalid multibyte character in parser at line ", capture(name = "line", digits))
@@ -280,6 +279,7 @@ lint_parse_error_nonstandard <- function(e, source_expression) {
         line = fixup_line(source_expression$lines[[l]])
       )
     )
+    # nocov end
   } else if (grepl("invalid multibyte string, element", e$message, fixed = TRUE)) {
     # Invalid encoding, will break even re_matches() below, so we need to handle this first.
     return(
@@ -293,6 +293,7 @@ lint_parse_error_nonstandard <- function(e, source_expression) {
       )
     )
   } else if (grepl("repeated formal argument", e$message, fixed = TRUE)) {
+    # nocov start: only throws on certain versions; tested on L389
     matches <- re_matches(
       e$message,
       rex(
@@ -315,6 +316,7 @@ lint_parse_error_nonstandard <- function(e, source_expression) {
         line = fixup_line(source_expression$lines[[l]])
       )
     )
+    # nocov end
   }
 
   # Hand-crafted regex to parse all error messages generated by the R parser code for R < 4.3.
@@ -325,8 +327,8 @@ lint_parse_error_nonstandard <- function(e, source_expression) {
   # parser_files <- c("src/main/gram.c", "src/main/character.c")
   #
   # lines <- unlist(lapply(
-  #   parser_files,
-  #   function(f) readLines(paste0("https://raw.githubusercontent.com/wch/r-source/trunk/", f))
+  #   file.path("https://raw.githubusercontent.com/wch/r-source/trunk", parser_files),
+  #   readLines
   # ))
   # error_calls <- grep("error(_(", lines, fixed = TRUE, value = TRUE)
   # error_formats <- trimws(gsub("^.*error\\(_\\(\"(.+)\".+", "\\1", error_calls))
@@ -344,6 +346,7 @@ lint_parse_error_nonstandard <- function(e, source_expression) {
   )
 
   if (grepl(parse_error_rx, e$message, perl = TRUE)) {
+    # nocov start: only throws on certain versions. Tested on L396: Nul character not allowed
     rx_match <- re_matches(
       e$message,
       parse_error_rx
@@ -365,6 +368,7 @@ lint_parse_error_nonstandard <- function(e, source_expression) {
         line = source_expression$lines[[l]]
       )
     )
+    # nocov end
   }
 
   message_info <- re_matches(
@@ -466,7 +470,6 @@ get_single_source_expression <- function(loc,
   content <- get_content(source_expression$lines, parsed_content[loc, ])
   id <- parsed_content$id[loc]
   pc <- parsed_content[which(top_level_map == id), ]
-  newline_locs <- get_newline_locs(content)
   list(
     filename = filename,
     line = parsed_content[loc, "line1"],
@@ -474,9 +477,7 @@ get_single_source_expression <- function(loc,
     lines = expr_lines,
     parsed_content = pc,
     xml_parsed_content = xml2::xml_missing(),
-    content = content,
-    find_line = find_line_fun(content, newline_locs),
-    find_column = find_column_fun(content, newline_locs)
+    content = content
   )
 }
 
@@ -538,7 +539,7 @@ get_newline_locs <- function(x) {
 # Fix column numbers when there are tabs
 # getParseData() counts 1 tab as a variable number of spaces instead of one:
 # https://github.com/wch/r-source/blame/e7401b68ab0e032fce3e376aaca9a5431619b2b4/src/main/gram.y#L512
-# The number of spaces is so that the code is brought to the next 8-character indentation level e.g:
+# The number of spaces is so that the code is brought to the next 8-character indentation level e.g.:
 #   "1\t;"          --> "1       ;"
 #   "12\t;"         --> "12      ;"
 #   "123\t;"        --> "123     ;"
@@ -615,7 +616,7 @@ fix_eq_assigns <- function(pc) {
 
   eq_assign_locs <- which(pc$token == "EQ_ASSIGN")
   # check whether the equal-assignment is the final entry
-  if (length(eq_assign_locs) == 0L || utils::tail(eq_assign_locs, 1L) == nrow(pc)) {
+  if (length(eq_assign_locs) == 0L || tail(eq_assign_locs, 1L) == nrow(pc)) {
     return(pc)
   }
 
@@ -660,12 +661,13 @@ fix_eq_assigns <- function(pc) {
     prev_loc <- prev_locs[start]
     next_loc <- next_locs[end]
 
+    id_itr <- id_itr + 1L
     supplemental_content[i, ] <- list(
       pc[prev_loc, "line1"],
       pc[prev_loc, "col1"],
       pc[next_loc, "line2"],
       pc[next_loc, "col2"],
-      id_itr <- id_itr + 1L,
+      id_itr,
       pc[eq_assign_locs[true_locs[i]], "parent"],
       "expr", # R now uses "equal_assign"
       FALSE,
