@@ -38,7 +38,7 @@ spaces_inside_linter <- function() {
     and @end != following-sibling::*[1]/@start - 1
     and @line1 = following-sibling::*[1]/@line1
   "
-  left_xpath <- glue::glue("
+  left_xpath <- glue("
   //OP-LEFT-BRACKET[{left_xpath_condition}]
   | //LBB[{left_xpath_condition}]
   | //OP-LEFT-PAREN[{left_xpath_condition}]")
@@ -48,7 +48,7 @@ spaces_inside_linter <- function() {
     and @start != preceding-sibling::*[1]/@end + 1
     and @line1 = preceding-sibling::*[1]/@line2
   "
-  right_xpath <- glue::glue("
+  right_xpath <- glue("
   //OP-RIGHT-BRACKET[{right_xpath_condition}]
   | //OP-RIGHT-PAREN[{right_xpath_condition} and not(preceding-sibling::*[1][self::EQ_SUB])]")
 
@@ -59,9 +59,9 @@ spaces_inside_linter <- function() {
 
     xml <- source_expression$full_xml_parsed_content
 
-    left_expr <- xml2::xml_find_all(xml, left_xpath)
+    left_expr <- xml_find_all(xml, left_xpath)
     left_msg <- ifelse(
-      xml2::xml_text(left_expr) %in% c("[", "[["),
+      xml_text(left_expr) %in% c("[", "[["),
       "Do not place spaces after square brackets.",
       "Do not place spaces after parentheses."
     )
@@ -74,9 +74,9 @@ spaces_inside_linter <- function() {
       range_end_xpath = "number(./following-sibling::*[1]/@col1 - 1)" # end before following expr
     )
 
-    right_expr <- xml2::xml_find_all(xml, right_xpath)
+    right_expr <- xml_find_all(xml, right_xpath)
     right_msg <- ifelse(
-      xml2::xml_text(right_expr) == "]",
+      xml_text(right_expr) == "]",
       "Do not place spaces before square brackets.",
       "Do not place spaces before parentheses."
     )
